@@ -2,25 +2,19 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-29 09:40:42
-:LastEditTime: 2021-02-24 15:59:04
+:LastEditTime: 2021-04-15 15:12:33
 :LastEditors: HuangJingCan
 :description: 机台（盒子）
 """
-import decimal
-from copy import deepcopy
 from seven_cloudapp.handlers.seven_base import *
 
-from seven_cloudapp.models.db_models.behavior.behavior_log_model import *
-from seven_cloudapp.models.db_models.behavior.behavior_orm_model import *
-from seven_cloudapp.models.db_models.behavior.behavior_report_model import *
-from seven_cloudapp.models.db_models.machine.machine_value_model import *
-from seven_cloudapp.models.db_models.machine.machine_value_log_model import *
-from seven_cloudapp.models.db_models.coin.coin_order_model import *
+from seven_cloudapp.models.enum import OperationType
 from seven_cloudapp.models.seven_model import PageInfo
 from seven_cloudapp.models.behavior_model import *
-from seven_cloudapp.models.enum import *
+from seven_cloudapp.models.db_models.machine.machine_value_model import *
 
 from seven_cloudapp.handlers.server.machine_s import MachineReleaseHandler
+from seven_cloudapp.handlers.server.machine_s import CheckBuyEndboxHandler
 
 from seven_cloudapp_ppmt.models.db_models.machine.machine_info_model import *
 from seven_cloudapp_ppmt.models.db_models.act.act_prize_model import *
@@ -63,12 +57,13 @@ class MachineHandler(SevenBaseHandler):
         many_lottery_num = int(self.get_param("many_lottery_num", 0))
         machine_price = decimal.Decimal(self.get_param("machine_price", "0.00"))
         is_repeat_prize = int(self.get_param("is_repeat_prize", 0))
+        is_buy_endbox = int(self.get_param("is_buy_endbox", 0))
 
         if act_id <= 0:
             return self.reponse_json_error_params()
 
         machine_info = None
-        machine_info_model = MachineInfoModel()
+        machine_info_model = MachineInfoModel(context=self)
         if machine_id > 0:
             machine_info = machine_info_model.get_entity_by_id(machine_id)
 
@@ -103,6 +98,7 @@ class MachineHandler(SevenBaseHandler):
         machine_info.many_lottery_num = many_lottery_num
         machine_info.machine_price = decimal.Decimal(machine_price)
         machine_info.is_repeat_prize = is_repeat_prize
+        machine_info.is_buy_endbox = is_buy_endbox
         machine_info.goods_modify_date = self.get_now_datetime()
         machine_info.modify_date = machine_info.goods_modify_date
 
@@ -136,9 +132,10 @@ class MachineHandler(SevenBaseHandler):
             behavior_orm.act_id = act_id
             behavior_orm.create_date = self.get_now_datetime()
             orm_infos.append(behavior_orm)
-        BehaviorModel().save_orm(orm_infos, act_id)
 
-        self.reponse_json_success(machine_info.id)
+        BehaviorModel(context=self).save_orm(orm_infos, act_id)
+
+        return self.reponse_json_success(machine_info.id)
 
 
 class MachineListHandler(SevenBaseHandler):
@@ -162,7 +159,7 @@ class MachineListHandler(SevenBaseHandler):
         if act_id <= 0:
             return self.reponse_json_error_params()
 
-        page_list, total = MachineInfoModel().get_dict_page_list("*", page_index, page_size, "act_id=%s", "", "sort_index desc", act_id)
+        page_list, total = MachineInfoModel(context=self).get_dict_page_list("*", page_index, page_size, "act_id=%s", "", "sort_index desc", act_id)
 
         for page in page_list:
             page["goods_detail"] = self.json_loads(page['goods_detail'])
@@ -170,7 +167,7 @@ class MachineListHandler(SevenBaseHandler):
 
         page_info = PageInfo(page_index, page_size, total, page_list)
 
-        self.reponse_json_success(page_info)
+        return self.reponse_json_success(page_info)
 
 
 class MachineDelHandler(SevenBaseHandler):
@@ -190,14 +187,14 @@ class MachineDelHandler(SevenBaseHandler):
         if machine_id <= 0:
             return self.reponse_json_error_params()
 
-        ActPrizeModel().del_entity("machine_id=%s", machine_id)
+        ActPrizeModel(context=self).del_entity("machine_id=%s", machine_id)
 
-        MachineInfoModel().del_entity("id=%s", machine_id)
+        MachineInfoModel(context=self).del_entity("id=%s", machine_id)
 
-        MachineValueModel().del_entity("machine_id=%s", machine_id)
+        MachineValueModel(context=self).del_entity("machine_id=%s", machine_id)
 
-        BehaviorOrmModel().del_entity("key_name='openUserCount_" + str(machine_id) + "' or key_name='openCount_" + str(machine_id) + "'")
+        BehaviorOrmModel(context=self).del_entity("key_name='openUserCount_" + str(machine_id) + "' or key_name='openCount_" + str(machine_id) + "'")
 
         self.create_operation_log(OperationType.delete.value, "machine_info_tb", "MachineDelHandler", None, machine_id)
 
-        self.reponse_json_success()
\ No newline at end of file
+        return self.reponse_json_success()
\ No newline at end of file
